==> owncloud-8.1.0p2.tgz: owncloud/apps/files/l10n/lv.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Glabātuve nav pieejama",
    "Storage invalid" : "Nepareiza krātuve",
    "Unknown error" : "Nezināma kļūda",
    "Could not move %s - File with this name already exists" : "Nevarēja pārvietot %s — jau eksistē datne ar tādu nosaukumu",
    "Could not move %s" : "Nevarēja pārvietot %s",
    "Permission denied" : "Pieeja liegta",
    "The target folder has been moved or deleted." : "Mērķa mape ir pārvietota vai dzēsta",
    "The name %s is already used in the folder %s. Please choose a different name." : "Nosaukums '%s' jau tiek izmantots mapē '%s'. Lūdzu izvēlieties citu nosaukumu.",
    "Error when creating the file" : "Kļūda veidojot datni",
    "Error when creating the folder" : "Kļūda, veidojot mapi",
    "Unable to set upload directory." : "Nevar uzstādīt augšupielādes mapi.",
    "Invalid Token" : "Nepareiza pilnvara",
    "No file was uploaded. Unknown error" : "Netika augšupielādēta neviena datne. Nezināma kļūda",
    "There is no error, the file uploaded with success" : "Viss kārtībā, datne augšupielādēta veiksmīga",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Augšupielādētā datne pārsniedz upload_max_filesize norādījumu php.ini datnē:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Augšupielādētā datne pārsniedz MAX_FILE_SIZE norādi, kas ir norādīta HTML formā",
    "The uploaded file was only partially uploaded" : "Augšupielādētā datne ir tikai daļēji augšupielādēta",
    "No file was uploaded" : "Neviena datne netika augšupielādēta",
    "Missing a temporary folder" : "Trūkst pagaidu mapes",
    "Failed to write to disk" : "Neizdevās saglabāt diskā",
    "Not enough storage available" : "Nav pietiekami daudz vietas",
    "Upload failed. Could not find uploaded file" : "Augšupielāde nesekmīga. Neizdevās atrast augšupielādēto failu.",
    "Upload failed. Could not get file info." : "Augšupielāde nesekmīga. Neizdevās iegūt informāciju par failu.",
    "Invalid directory." : "Nederīga direktorija.",
    "Files" : "Datnes",
    "All files" : "Visas datnes",
    "Favorites" : "Iecienītie",
    "Home" : "Mājas",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Neizdodas augšupielādēt {filename}, jo tā ir vai nu mape vai 0 baitu saturošs fails.",
    "Total file size {size1} exceeds upload limit {size2}" : "Kopējais faila izmērs {size1} pārsniedz augšupielādes ierobežojumu {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nav pietiekami daudz brīvas vietas. Tiek augšupielādēti {size1}, bet pieejami tikai {size2}",
    "Upload cancelled." : "Augšupielāde ir atcelta.",
    "Could not get result from server." : "Nevar saņemt rezultātus no servera",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Notiek augšupielāde. Pametot lapu tagad, tiks atcelta augšupielāde.",
    "{new_name} already exists" : "{new_name} jau eksistē",
    "Could not create file" : "Neizdevās izveidot datni",
    "Could not create folder" : "Neizdevās izveidot mapi",
    "Rename" : "Pārsaukt",
    "Delete" : "Dzēst",
    "Disconnect storage" : "Atvienot krātuvi",
    "Unshare" : "Pārtraukt dalīšanos",
    "Download" : "Lejupielādēt",
    "Select" : "Norādīt",
    "Pending" : "Gaida savu kārtu",
    "Unable to determine date" : "Neizdevās noteikt datumu",
    "Error moving file." : "Kļūda, pārvietojot datni.",
    "Error moving file" : "Kļūda, pārvietojot datni",
    "Error" : "Kļūda",
    "Could not rename file" : "Neizdevās pārsaukt datni",
    "Error deleting file." : "Kļūda, dzēšot datni.",
    "No entries in this folder match '{filter}'" : "Šajā mapē nekas nav atrasts, meklējot pēc '{filter}'",
    "Name" : "Nosaukums",
    "Size" : "Izmērs",
    "Modified" : "Mainīts",
    "_%n folder_::_%n folders_" : ["%n mapes","%n mape","%n mapes"],
    "_%n file_::_%n files_" : ["%n faili","%n fails","%n faili"],
    "You don’t have permission to upload or create files here" : "Jums nav tiesību, augšupielādēt vai veidot, šeit datnes",
    "_Uploading %n file_::_Uploading %n files_" : ["%n","Augšupielāde %n failu","Augšupielāde %n failus"],
    "\"{name}\" is an invalid file name." : "\"{name}\" ir nepareizs datnes nosaukums.",
    "File name cannot be empty." : "Datnes nosaukums nevar būt tukšs.",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsu krātuve ir pilna, datnes vairs nevar augšupielādēt vai sinhronizēt!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsu krātuve ir gandrīz pilna ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["atrasts pēc '{filter}'","atrasts pēc '{filter}'","atrasti pēc '{filter}'"],
    "{dirs} and {files}" : "{dirs} un {files}",
    "Favorited" : "Favorīti",
    "Favorite" : "Iecienītais",
    "An error occurred while trying to update the tags" : "Atjaunojot atzīmes notika kļūda",
    "A new file or folder has been <strong>created</strong>" : "<strong>Izveidots</strong> jauns fails vai mape",
    "A file or folder has been <strong>changed</strong>" : "<strong>Izmainīts</strong> fails vai mape",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Dzēsts</strong> fails vai mape",
    "A file or folder has been <strong>restored</strong>" : "<strong>Atjaunots</strong> fails vai mape",
    "You created %1$s" : "Tu izveidoji %1$s",
    "%2$s created %1$s" : "%2$s izveidoja %1$s",
    "%1$s was created in a public folder" : "%1$s tika izveidots publiskajā mapē",
    "You changed %1$s" : "Tu izmainīji %1$s",
    "%2$s changed %1$s" : "%2$s izmainīja %1$s",
    "You deleted %1$s" : "Tu izdzēsi %1$s",
    "%2$s deleted %1$s" : "%2$s izdzēsa %1$s",
    "You restored %1$s" : "Tu atjaunoji %1$s",
    "%2$s restored %1$s" : "%2$s atjaunoja %1$s",
    "%s could not be renamed as it has been deleted" : "Nevarēja pārsaukt %s, jo tas ir dzēsts",
    "%s could not be renamed" : "%s nevar tikt pārsaukts",
    "Upload (max. %s)" : "Augšupielādēt (maks. %s)",
    "File handling" : "Datņu pārvaldība",
    "Maximum upload size" : "Maksimālais datņu augšupielādes apjoms",
    "max. possible: " : "maksimālais iespējamais:",
    "Save" : "Saglabāt",
    "Settings" : "Iestatījumi",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Izmantojot šo adresi, <a href=\"%s\" target=\"_blank\">piekļūstiet saviem failiem, izmantojot WebDAV</a>",
    "New" : "Jauna",
    "New text file" : "Jauna teksta datne",
    "Text file" : "Teksta datne",
    "New folder" : "Jauna mape",
    "Folder" : "Mape",
    "Upload" : "Augšupielādēt",
    "Cancel upload" : "Atcelt augšupielādi",
    "Upload some content or sync with your devices!" : "Augšupielādē kaut ko vai sinhronizē saturu ar savām ierīcēm!",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Select all" : "Atzīmēt visu",
    "Upload too large" : "Datne ir par lielu, lai to augšupielādētu",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Augšupielādējamās datnes pārsniedz servera pieļaujamo datņu augšupielādes apjomu",
    "Files are being scanned, please wait." : "Datnes šobrīd tiek caurskatītas, lūdzu, uzgaidiet.",
    "Currently scanning" : "Pašlaik skenē",
    "No favorites" : "Nav favorītu",
    "Files and folders you mark as favorite will show up here" : "Faili un mapes, ko atzīmēsit kā favorītus, tiks rādīti šeit"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> owncloud-9.0.3.tgz: owncloud/apps/files/l10n/lv.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Glabātuve nav pieejama",
    "Storage invalid" : "Nepareiza krātuve",
    "Unknown error" : "Nezināma kļūda",
    "Unable to set upload directory." : "Nevar uzstādīt augšupielādes mapi.",
    "Invalid Token" : "Nepareiza pilnvara",
    "No file was uploaded. Unknown error" : "Netika augšupielādēta neviena datne. Nezināma kļūda",
    "There is no error, the file uploaded with success" : "Viss kārtībā, datne augšupielādēta veiksmīga",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Augšupielādētā datne pārsniedz upload_max_filesize norādījumu php.ini datnē:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Augšupielādētā datne pārsniedz MAX_FILE_SIZE norādi, kas ir norādīta HTML formā",
    "The uploaded file was only partially uploaded" : "Augšupielādētā datne ir tikai daļēji augšupielādēta",
    "No file was uploaded" : "Neviena datne netika augšupielādēta",
    "Missing a temporary folder" : "Trūkst pagaidu mapes",
    "Failed to write to disk" : "Neizdevās saglabāt diskā",
    "Not enough storage available" : "Nav pietiekami daudz vietas",
    "The target folder has been moved or deleted." : "Mērķa mape ir pārvietota vai dzēsta",
    "Upload failed. Could not find uploaded file" : "Augšupielāde nesekmīga. Neizdevās atrast augšupielādēto failu.",
    "Upload failed. Could not get file info." : "Augšupielāde nesekmīga. Neizdevās iegūt informāciju par failu.",
    "Invalid directory." : "Nederīga direktorija.",
    "Files" : "Datnes",
    "All files" : "Visas datnes",
    "Favorites" : "Iecienītie",
    "Home" : "Mājas",
    "Close" : "Aizvērt",
    "Upload cancelled." : "Augšupielāde ir atcelta.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Neizdodas augšupielādēt {filename}, jo tā ir vai nu mape vai 0 baitu saturošs fails.",
    "Total file size {size1} exceeds upload limit {size2}" : "Kopējais faila izmērs {size1} pārsniedz augšupielādes ierobežojumu {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nav pietiekami daudz brīvas vietas. Tiek augšupielādēti {size1}, bet pieejami tikai {size2}",
    "Could not get result from server." : "Nevar saņemt rezultātus no servera",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Notiek augšupielāde. Pametot lapu tagad, tiks atcelta augšupielāde.",
    "Actions" : "Darbības",
    "Download" : "Lejupielādēt",
    "Rename" : "Pārsaukt",
    "Delete" : "Dzēst",
    "Disconnect storage" : "Atvienot krātuvi",
    "Unshare" : "Pārtraukt dalīšanos",
    "Details" : "Detaļas",
    "Select" : "Norādīt",
    "Pending" : "Gaida savu kārtu",
    "Unable to determine date" : "Neizdevās noteikt datumu",
    "No entries in this folder match '{filter}'" : "Šajā mapē nekas nav atrasts, meklējot pēc '{filter}'",
    "Name" : "Nosaukums",
    "Size" : "Izmērs",
    "Modified" : "Mainīts",
    "_%n folder_::_%n folders_" : ["%n mapes","%n mape","%n mapes"],
    "_%n file_::_%n files_" : ["%n faili","%n fails","%n faili"],
    "{dirs} and {files}" : "{dirs} un {files}",
    "You don’t have permission to upload or create files here" : "Jums nav tiesību, augšupielādēt vai veidot, šeit datnes",
    "_Uploading %n file_::_Uploading %n files_" : ["%n","Augšupielāde %n failu","Augšupielāde %n failus"],
    "New" : "Jauna",
    "\"{name}\" is an invalid file name." : "\"{name}\" ir nepareizs datnes nosaukums.",
    "File name cannot be empty." : "Datnes nosaukums nevar būt tukšs.",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsu krātuve ir pilna, datnes vairs nevar augšupielādēt vai sinhronizēt!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsu krātuve ir gandrīz pilna ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["atrasts pēc '{filter}'","atrasts pēc '{filter}'","atrasti pēc '{filter}'"],
    "Favorited" : "Favorīti",
    "Favorite" : "Iecienītais",
    "Folder" : "Mape",
    "New folder" : "Jauna mape",
    "Upload" : "Augšupielādēt",
    "An error occurred while trying to update the tags" : "Atjaunojot atzīmes notika kļūda",
    "A new file or folder has been <strong>created</strong>" : "<strong>Izveidots</strong> jauns fails vai mape",
    "A file or folder has been <strong>changed</strong>" : "<strong>Izmainīts</strong> fails vai mape",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Dzēsts</strong> fails vai mape",
    "A file or folder has been <strong>restored</strong>" : "<strong>Atjaunots</strong> fails vai mape",
    "You created %1$s" : "Tu izveidoji %1$s",
    "%2$s created %1$s" : "%2$s izveidoja %1$s",
    "%1$s was created in a public folder" : "%1$s tika izveidots publiskajā mapē",
    "You changed %1$s" : "Tu izmainīji %1$s",
    "%2$s changed %1$s" : "%2$s izmainīja %1$s",
    "You deleted %1$s" : "Tu izdzēsi %1$s",
    "%2$s deleted %1$s" : "%2$s izdzēsa %1$s",
    "You restored %1$s" : "Tu atjaunoji %1$s",
    "%2$s restored %1$s" : "%2$s atjaunoja %1$s",
    "Upload (max. %s)" : "Augšupielādēt (maks. %s)",
    "File handling" : "Datņu pārvaldība",
    "Maximum upload size" : "Maksimālais datņu augšupielādes apjoms",
    "max. possible: " : "maksimālais iespējamais:",
    "Save" : "Saglabāt",
    "Settings" : "Iestatījumi",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Izmantojot šo adresi, <a href=\"%s\" target=\"_blank\">piekļūstiet saviem failiem, izmantojot WebDAV</a>",
    "Cancel upload" : "Atcelt augšupielādi",
    "Upload some content or sync with your devices!" : "Augšupielādē kaut ko vai sinhronizē saturu ar savām ierīcēm!",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Select all" : "Atzīmēt visu",
    "Upload too large" : "Datne ir par lielu, lai to augšupielādētu",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Augšupielādējamās datnes pārsniedz servera pieļaujamo datņu augšupielādes apjomu",
    "No favorites" : "Nav favorītu",
    "Files and folders you mark as favorite will show up here" : "Faili un mapes, ko atzīmēsit kā favorītus, tiks rādīti šeit",
    "Text file" : "Teksta datne",
    "You changed %1$s" : "Tu izmainīji %1$s",
    "You created %1$s" : "Tu izveidoji %1$s",
    "You deleted %1$s" : "Tu izdzēsi %1$s",
    "You restored %1$s" : "Tu atjaunoji %1$s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
